package com.isu.gaswellwatch.controller;

import java.util.Collection;
import java.util.List;

import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.isu.gaswellwatch.service.BlockService;
import com.isu.gaswellwatch.entity.Response;
import com.isu.gaswellwatch.enums.LogType;
import com.isu.gaswellwatch.dto.BlockCreateRequest;
import com.isu.gaswellwatch.dto.BlockEditRequest;
import com.isu.gaswellwatch.vo.BlockPageQuery;
import com.isu.gaswellwatch.vo.BlockVO;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.isu.gaswellwatch.annotation.OperationLog;
import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;

/**
 * 区块管理
 *
 * @author scwsl
 * @date 2024-11-17
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/blocks")
public class BlockController {

    private final BlockService blockService;

    /**
     * 查询区块列表
     */
    @GetMapping
    public Response<Page<BlockVO>> page(BlockPageQuery query) {
        return Response.succeed(blockService.pageForQuery(query));
    }

    /**
     * 获取区块详细信息
     */
    @GetMapping(value = "/{id}")
    public Response<BlockVO> getInfo(@PathVariable("id") Long id) {
        return Response.succeed(blockService.selectBlockById(id));
    }

    /**
     * 新增区块
     */
    @PostMapping
    @OperationLog(description = "新增区块", type = LogType.ADD)
    public Response<String> add(@RequestBody @Valid BlockCreateRequest blockCreateRequest) {
            blockService.insertBlock(blockCreateRequest);
        return Response.succeed();
    }

    /**
     * 修改区块
     */
    @PutMapping
    @OperationLog(description = "修改区块", type = LogType.UPDATE)
    public Response<String> edit(@RequestBody BlockEditRequest blockEditRequest) {
            blockService.updateBlock(blockEditRequest);
        return Response.succeed();
    }

    /**
     * 删除区块
     */
    @DeleteMapping("/{ids}")
    @OperationLog(description = "删除区块", type = LogType.DELETE)
    public Response<String> delete(@PathVariable Collection<Long> ids) {
            blockService.deleteBlockByIds(ids);
        return Response.succeed();
    }

}
