package com.isu.gaswellwatch.modbus.data.decode.impl;

import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import com.serotonin.modbus4j.msg.ReadInputRegistersResponse;
import com.serotonin.modbus4j.serial.rtu.RtuMessageParser;
import com.serotonin.modbus4j.serial.rtu.RtuMessageResponse;
import com.serotonin.modbus4j.sero.util.queue.ByteQueue;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.amqp.core.Message;
import org.springframework.data.redis.core.HashOperations;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

/**
 * KNPCV1 柱塞器解析
 *
 * @author <a href="mailto:shilong.wang@alpha-ess.com">王仕龙</a>
 * 2024/11/23 11:23
 */
@RequiredArgsConstructor
@Component(Knpcv1DecodeHandler.MODBUS_DEVICE_TYPE)
public class Knpcv1DecodeHandler implements DecodeHandler {

    public static final String MODBUS_DEVICE_TYPE = "KNPCV1";
    private final RedisTemplate<String, Object> redisTemplate;

    @Override
    public void decode(Message message) throws Exception {

        // /device/4B454E454E4731343030303030333538/collect
        String queueName = message.getMessageProperties().getConsumerQueue();
        String messageString = new String(message.getBody());
        HashOperations<String, Object, Object> hashOperations = this.redisTemplate.opsForHash();
        String[] queuePath = StringUtils.split(queueName, "/");
        String deviceId = queuePath[1];
        String command = queuePath[2];

        logger.info("Decode {}, Queue {}, Message {}", MODBUS_DEVICE_TYPE, queueName, messageString);

        ByteQueue byteQueue = new ByteQueue(messageString.replaceAll(" ", ""));
        RtuMessageParser masterParser = new RtuMessageParser(true);
        RtuMessageResponse response = (RtuMessageResponse) masterParser.parseMessage(byteQueue);
        ReadInputRegistersResponse readInputRegistersResponse = (ReadInputRegistersResponse) response.getModbusResponse();
        int index = 0;
        hashOperations.put(queueName, DecodeHandler.MODBUS_DEVICE_TYPE_FIELD_NAME, MODBUS_DEVICE_TYPE);
        for (short value : readInputRegistersResponse.getShortData()) {
            hashOperations.put(queueName, StringUtils.leftPad(String.valueOf(index++), 4, '0'), value);
        }
    }

}
