package com.isu.gaswellwatch.service.impl;

import java.util.Collection;
import java.util.List;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.isu.gaswellwatch.dto.GasWellCreateRequest;
import com.isu.gaswellwatch.dto.GasWellEditRequest;
import com.isu.gaswellwatch.vo.GasWellPageQuery;
import com.isu.gaswellwatch.vo.GasWellVO;
import com.isu.gaswellwatch.dao.GasWellDao;
import com.isu.gaswellwatch.entity.GasWell;
import com.isu.gaswellwatch.service.GasWellService;
import com.isu.gaswellwatch.mapper.GasWellMapper;
import org.mapstruct.factory.Mappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * 气井Service业务层处理
 * 
 * @author scwsl
 * @date 2024-11-17
 */
@Service
@RequiredArgsConstructor
@Transactional(readOnly = true)
public class GasWellServiceImpl  extends ServiceImpl<GasWellDao, GasWell> implements GasWellService {

    private final GasWellDao gasWellDao;
    private final GasWellMapper gasWellMapper = Mappers.getMapper(GasWellMapper.class);

    /**
     * 查询气井
     * 
     * @param id 气井主键
     * @return 气井
     */
    @Override
    public GasWellVO selectGasWellById(Long id) {
        return gasWellMapper.toPageVO(gasWellDao.selectGasWellById(id));
    }

    /**
     * 查询气井列表
     * 
     * @param gasWell 气井
     * @return 气井
     */
    @Override
    public List<GasWellVO> selectGasWellList(GasWell gasWell) {
        return gasWellMapper.toPageVO(gasWellDao.selectGasWellList(gasWell));
    }

    /**
     * 分页查询气井列表
     *
     * @param query 查询条件
     * @return 气井
     */
    @Override
    public Page<GasWellVO> pageForQuery(GasWellPageQuery query){
        return gasWellDao.pageForQuery(new Page<>(query.getCurrentPage(), query.getPageSize()), query);
    }

    /**
     * 新增气井
     * 
     * @param gasWellCreateRequest 气井
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Throwable.class)
    public int insertGasWell(GasWellCreateRequest gasWellCreateRequest) {
        return gasWellDao.insertGasWell(gasWellMapper.create(gasWellCreateRequest));
    }

    /**
     * 修改气井
     * 
     * @param gasWellEditRequest 气井
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Throwable.class)
    public int updateGasWell(GasWellEditRequest gasWellEditRequest) {
        GasWell gasWell = gasWellDao.selectGasWellById(gasWellEditRequest.getId());
        gasWellMapper.copyToEntity(gasWellEditRequest, gasWell);
        return gasWellDao.updateGasWell(gasWell);
    }

    /**
     * 删除气井信息
     * 
     * @param id 气井主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Throwable.class)
    public int deleteGasWellById(Long id) {
        return gasWellDao.deleteGasWellById(id);
    }

    /**
     * 批量删除删除气井信息
     *
     * @param ids 气井主键
     * @return 数量
     */
    @Override
    @Transactional(rollbackFor = Throwable.class)
    public int deleteGasWellByIds(Collection<Long> ids) {
        return gasWellDao.deleteGasWellByIds(ids);
    }

}
